@@ -9,4 +9,7 @@ pub mod many_to_many;
 pub use one_to_one::OneToOne;
 pub use one_to_many::OneToMany;
 pub use many_to_one::ManyToOne;
-pub use many_to_many::ManyToMany;
\ No newline at end of file
+pub use many_to_many::ManyToMany;
+
+#[cfg(feature="serde1")]
+mod serde_impl;
\ No newline at end of file
