@@ -1,6 +1,8 @@
 mod backward;
 mod forward;
 mod structure;
+mod extra;
+mod fwd_set_extra;
 
 pub use self::structure::OneToMany;
 pub use self::forward::{Fwd, FwdSet};
